@@ -1,3 +1,4 @@
+from six import u
 from starterpyth.fields import BooleanInput
 
 __author__ = 'd9pouces'
@@ -19,11 +20,12 @@ class CythonPlugin(Plugin):
         self.selected = BooleanInput(_('Create a Cython application'), default=True).input()
         if not self.selected:
             return
-        context['doc_urls']['cython'] = ('http://docs.cython.org/', 'externals/cython_0.19.inv')
+        context['doc_urls']['cython'] = (u('http://docs.cython.org/'), u('externals/cython_0.19.inv'))
 #        context['ext_modules'].append('Extension("sample_cython", ["sample_cython.pyx"])')
 #        context['extra_imports'].append(('distutils.extension', 'Extension', None))
 #        context['extra_imports'].append(('Cython.Distutils', 'build_ext', 'cython_build_ext'))
-        cython_setup = self.get_template(context, 'starterpyth.plugins.starter_cython', 'extra_templates/setup.py_tpl')
+        cython_setup = self.get_template(context, u('starterpyth.plugins.starter_cython'),
+                                         u('extra_templates/setup.py_tpl'))
         context['extra_setup'].append(cython_setup)
 
     def get_resources(self):
